@@ -4,7 +4,7 @@ use 5.008008;
 use strict;
 use warnings;
 
-our $VERSION = '2.22';
+our $VERSION = '2.3';
 
 use Text::Sentence qw( split_sentences );
 use Lingua::NegEx qw( negation_scope );
@@ -119,16 +119,21 @@ sub examine_text {
 
 sub debug {
   my $self = shift;
-  my $out = "DxExtractor Debug:\n";
-  $out .= "Target Words: " . (join ', ', @{$self->target_phrases}) . "\n";
-  $out .= "Skip Words: " . (join ', ', @{$self->skip_phrases}) . "\n";
-  $out .= "Sentences:\n";
+  my $out = "Target Phrases(" . (join ', ', map { qq{'$_'} } @{$self->target_phrases}) . ")\r\n\r\n";
+  $out .= "Skip Phrases(" . (join ', ', map { qq{'$_'} } @{$self->skip_phrases}) . ")\r\n\r\n" if $self->skip_phrases;
+  $out .= "Absolute Present Phrases(" . (join ', ', map { qq{'$_'} } @{$self->absolute_present_phrases}) . ")\r\n\r\n" if $self->absolute_present_phrases;
+  $out .= "Absolute Negative Phrases(" . (join ', ', map { qq{'$_'} } @{$self->absolute_negative_phrases}) . ")\r\n\r\n" if $self->absolute_negative_phrases;
+  $out .= "Start Phrase( '" . $self->start_phrase . "' )\r\n\r\n" if $self->start_phrase;
+  
+  $out .= "Sentences with a target phrase match:\r\n";
+  my $count = 1;
   while ( my($sentence,$answer) = each %{$self->target_sentence} ) {
-    $out .= "$sentence\n$answer\n"; 
-    $out .= "NegEx: " . $self->negex_debug->{ $sentence } . "\n";
+    $out .= "$count) $sentence -- $answer. "; 
+	$count++;
+    $out .= "NegEx: " . ($self->negex_debug->{ $sentence } || 'None') . "\r\n";
   }
-  $out .= "Final Answer: " . $self->final_answer . "\n";;
-  $out .= "Ambiguous: " . ($self->ambiguous ? 'Yes' : 'No');
+  $out .= "\r\nAmbiguous: " . ($self->ambiguous ==  1 ? 'Yes' : ( $self->ambiguous == 2 ? 'Absolute Present Phrase was present but the answer was going to be absent.' : ( $self->ambiguous == 3 ? 'Absolute Negative Phrase was present but the answer was going to be present.' : 'No' ) ) );
+  $out .= "\r\nFinal Answer: " . $self->final_answer . "\r\n";
   return $out;
 }
 
@@ -182,9 +187,13 @@ The radiographic reports don't require textual preprocessing however clearly the
 
 Negated terms are identified using Lingua::NegEx which is a perl implementation of Wendy Chapman's NegEx algorithm.
 
+=head2 GETTING STARTED
+
+Create a new extractor object with  your extraction rules:
+
   target_phrases( \@words );
 
-This is a list of phrases that describe the clinical entity in question. All forms of the entity in question need to explicitly stated since the package is currently not using lemmatization or stemming.
+This is a list of phrases that describe the clinical entity in question. All forms of the entity in question need to explicitly stated since the package is currently not using lemmatization or stemming. This is the only required parameter for the extractor object.
 
   skip_phrases( \@skip );
 
@@ -202,23 +211,9 @@ This is a list of phrases which if present in the text mean the condition is cer
 
 A phrase if present in the text which indicates where to focus the search.
 
-=head2 GETTING STARTED
+=head2 Analysis
 
-Define your extraction rules:
-
-1. Choose your target phrases that describe the condition of interest.
-
-2. Choose any skip phrases that will eliminate a sentence from an analysis if the phrase exists. For example, many radiology reports may have a sentence that states the indication for the study which might state the condition you are looking for but doesn't indicate that the condition was found in the study.
-
-3. Choose any absolute present phrases to use which are phrases that if they are present in the text mean the condition is certainly there and all ambiguity checking can be skipped.
-
-4. Choose any absolute negative phrases that mean the condition is absolutely not present and all ambiguity checking can be skipped.
-
-5. Choose a start phrase which can be used to focus the search to only the text that occurs after this start phrase. For example, if there is an 'Impression:' section at the end of a report that summarizes findings then skip to that section to avoid possible ambiguity generated by the verbose description of findings in the full report.
-	
-* Only the target phrases are required.
-	
-Once defined the extractor object you created can be used to analyze target text. The analysis consists of:
+Once defined, the extractor object you created can be used to analyze target text. The analysis consists of:
 
 1. If there is a start phrase defined, eliminate all text for analysis prior to the start phrase.
 
@@ -256,7 +251,7 @@ Add lemmatization or stemming to target_phrases so you don't have to explicitly
 
 =head1 AUTHOR
 
-Eduardp Iturrate, E<lt>ed@iturrate.comE<gt>
+Eduardo Iturrate, <lt>ed@iturrate.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
